@@ -6,14 +6,14 @@ module M
         []
       end
 
-      def run(_test_arguments)
+      def run _test_arguments
         not_supported
       end
 
       private
 
       def not_supported
-        STDERR.puts "This test framework is not supported! Please open up an issue at https://github.com/qrush/m !"
+        warn "This test framework is not supported! Please open up an issue at https://github.com/qrush/m !"
         false
       end
     end
