@@ -3,14 +3,14 @@ module M
     attr_accessor :file, :recursive, :passthrough_options
     attr_reader :lines
 
-    def initialize(file = "", lines = [], recursive = false)
+    def initialize file = "", lines = [], recursive = false
       @file = file
       @recursive = recursive
       @passthrough_options = []
       self.lines = lines
     end
 
-    def lines=(lines)
+    def lines= lines
       @lines = lines.map(&:to_i)
     end
   end
