@@ -1,8 +1,8 @@
-require 'active_support'
-require 'active_support/test_case'
+require "active_support"
+require "active_support/test_case"
 
 class MultipleExampleTest < ActiveSupport::TestCase
-  %w(grape habanero iceplant).each do |fruit|
+  ["grape", "habanero", "iceplant"].each do |fruit|
     test "#{fruit} is a fruit" do
       assert_equal 1, 1
     end
