@@ -1,5 +1,5 @@
-require_relative '../test_helper'
-try_loading('test-unit')
+require_relative "../test_helper"
+try_loading "test-unit"
 
 if M::Frameworks.test_unit?
   class TestUnitExampleTest < Test::Unit::TestCase
